Learn R Programming

mhcnuggetsr (version 1.1)

check_mhcnuggets_installation: Check if MHCnuggets is installed.

Description

Check if MHCnuggets is installed. Will stop if not.

Usage

check_mhcnuggets_installation(
  folder_name = get_default_mhcnuggets_folder(),
  mhcnuggets_url = get_mhcnuggets_url()
)

Arguments

folder_name

superfolder of MHCnuggets. The name of the superfolder is /home/[user_name]/.local/share by default, as can be obtained byget_default_mhcnuggets_folder

mhcnuggets_url

URL to the MHCnuggets GitHub repository

Value

Nothing.

Details

An MHCnuggets installation has two parts:

  1. The installation of the Python package, for running the code

  2. The download of the Python source code, which allows the use of example files

Examples

Run this code
# NOT RUN {
if (is_mhcnuggets_installed()) {
  check_mhcnuggets_installation()
}
# }

Run the code above in your browser using DataLab