Learn R Programming

mhcnuggetsr (version 1.1)

check_mhcnuggets_options_names: Check the names of the elements in an mhcnuggets_options list.

Description

Check the names of the elements in an mhcnuggets_options list. Will stop if an element is missing.

Usage

check_mhcnuggets_options_names(mhcnuggets_options)

Arguments

mhcnuggets_options

options to run MHCnuggets with, as can be created by create_mhcnuggets_options.

Examples

Run this code
# NOT RUN {
if (is_mhcnuggets_installed()) {
  check_mhcnuggets_options_names(
    create_test_mhcnuggets_options()
  )
}
# }

Run the code above in your browser using DataLab