powered by
Create a set of testing options to run MHCnuggets with. The most important setting is the use of a specific haplotype.
create_test_mhcnuggets_options( mhc_class = NA, mhc = "HLA-A02:01", ba_models = FALSE, verbose = FALSE, folder_name = get_default_mhcnuggets_folder(), mhcnuggets_url = get_mhcnuggets_url() )
MHC class. Must be I, II or NA. Use NA to let the class be deduced automatically
I
II
the MHC haplotype name
Set to TRUE to use a pure BA model
set to TRUE for more debug information
superfolder of MHCnuggets. The name of the superfolder is /home/[user_name]/.local/share by default, as can be obtained byget_default_mhcnuggets_folder
/home/[user_name]/.local/share
URL to the MHCnuggets GitHub repository
# NOT RUN { if (is_mhcnuggets_installed()) { create_test_mhcnuggets_options() } # }
Run the code above in your browser using DataLab