Learn R Programming

mhcnuggetsr (version 1.1)

get_default_mhcnuggets_folder: Get the path to the folder where this package installs MHCnuggets by default

Description

Get the path to the folder where this package installs MHCnuggets by default

Usage

get_default_mhcnuggets_folder()

Arguments

Value

the path to the folder where this package installs MHCnuggets by default

Examples

Run this code
# NOT RUN {
get_default_mhcnuggets_folder()
# }

Run the code above in your browser using DataLab