Learn R Programming

mhcnuggetsr (version 1.1)

is_mhcnuggets_name: Is this an MHCnuggets name?

Description

Determine if an HLA haplotype name follow the name format that MHCnuggets uses internally

Usage

is_mhcnuggets_name(mhc)

Arguments

mhc

the MHC haplotype name

Value

TRUE if the name follows the MHCnuggets naming convention

Examples

Run this code
# NOT RUN {
# The official name is not the name format used by MHCnuggets
is_mhcnuggets_name("HLA-A*01:01")

# MHCnuggets uses names without the asterisk
is_mhcnuggets_name("HLA-A01:01")
# }

Run the code above in your browser using DataLab