Learn R Programming

mhcnuggetsr (version 1.1)

is_on_ci: Determines if the environment is a continuous integration service

Description

Determines if the environment is a continuous integration service

Usage

is_on_ci()

Arguments

Value

TRUE if run on AppVeyor or Travis CI, FALSE otherwise

Examples

Run this code
# NOT RUN {
is_on_ci()
# }

Run the code above in your browser using DataLab