Learn R Programming

mhcnuggetsr (version 1.1)

set_pip_version: Set the version of pip.

Description

Set the version of pip to a specific version, by installing that version.

Usage

set_pip_version(version)

Arguments

version

pip version

Value

Nothing

See Also

use upgrade_pip to set pip to the latest version. Use downgrade_pip to set pip to a specific earlier version.

Examples

Run this code
# NOT RUN {
  if (is_pip_installed()) {
    set_pip_version("19.0")
  }
# }

Run the code above in your browser using DataLab