Learn R Programming

mhcnuggetsr (version 1.1)

to_mhcnuggets_names: Convert one or more standard haplotype name to the MHCnuggets names

Description

Convert one or more standard haplotype names to the MHCnuggets names. Will stop if this conversion fails.

Usage

to_mhcnuggets_names(mhcs)

Arguments

mhcs

the MHC haplotype names

Value

the MHCnuggets names for the haplotypes

Examples

Run this code
# NOT RUN {
to_mhcnuggets_names("HLA-A*01:01")
# }

Run the code above in your browser using DataLab