powered by
Get the path to the folder where this package installs MHCnuggets by default
get_default_mhcnuggets_folder()
the path to the folder where this package installs MHCnuggets by default
# NOT RUN { get_default_mhcnuggets_folder() # }
Run the code above in your browser using DataLab