powered by
Determine if an HLA haplotype name follow the name format that MHCnuggets uses internally
is_mhcnuggets_name(mhc)
the MHC haplotype name
TRUE if the name follows the MHCnuggets naming convention
# NOT RUN { # The official name is not the name format used by MHCnuggets is_mhcnuggets_name("HLA-A*01:01") # MHCnuggets uses names without the asterisk is_mhcnuggets_name("HLA-A01:01") # }
Run the code above in your browser using DataLab