powered by
Set the version of pip to a specific version, by installing that version.
set_pip_version(version)
pip version
Nothing
use upgrade_pip to set pip to the latest version. Use downgrade_pip to set pip to a specific earlier version.
# NOT RUN { if (is_pip_installed()) { set_pip_version("19.0") } # }
Run the code above in your browser using DataLab